==> interchain-rpc-1.3.0.tgz: package/src/codegen/cosmos/mint/v1beta1/mint.ts <==
import * as _m0 from "protobufjs/minimal";
import { DeepPartial, Long } from "../../../helpers";
/** Minter represents the minting state. */

export interface Minter {
  /** current annual inflation rate */
  inflation: string;
  /** current annual expected provisions */

  annualProvisions: string;
}
/** Minter represents the minting state. */

export interface MinterSDKType {
  /** current annual inflation rate */
  inflation: string;
  /** current annual expected provisions */

  annual_provisions: string;
}
/** Params holds parameters for the mint module. */

export interface Params {
  /** type of coin to mint */
  mintDenom: string;
  /** maximum annual change in inflation rate */

  inflationRateChange: string;
  /** maximum inflation rate */

  inflationMax: string;
  /** minimum inflation rate */

  inflationMin: string;
  /** goal of percent bonded atoms */

  goalBonded: string;
  /** expected blocks per year */

  blocksPerYear: Long;
}
/** Params holds parameters for the mint module. */

export interface ParamsSDKType {
  /** type of coin to mint */
  mint_denom: string;
  /** maximum annual change in inflation rate */

  inflation_rate_change: string;
  /** maximum inflation rate */

  inflation_max: string;
  /** minimum inflation rate */

  inflation_min: string;
  /** goal of percent bonded atoms */

  goal_bonded: string;
  /** expected blocks per year */

  blocks_per_year: Long;
}

function createBaseMinter(): Minter {
  return {
    inflation: "",
    annualProvisions: ""
  };
}

export const Minter = {
  encode(message: Minter, writer: _m0.Writer = _m0.Writer.create()): _m0.Writer {
    if (message.inflation !== "") {
      writer.uint32(10).string(message.inflation);
    }

    if (message.annualProvisions !== "") {
      writer.uint32(18).string(message.annualProvisions);
    }

    return writer;
  },

  decode(input: _m0.Reader | Uint8Array, length?: number): Minter {
    const reader = input instanceof _m0.Reader ? input : new _m0.Reader(input);
    let end = length === undefined ? reader.len : reader.pos + length;
    const message = createBaseMinter();

    while (reader.pos < end) {
      const tag = reader.uint32();

      switch (tag >>> 3) {
        case 1:
          message.inflation = reader.string();
          break;

        case 2:
          message.annualProvisions = reader.string();
          break;

        default:
          reader.skipType(tag & 7);
          break;
      }
    }

    return message;
  },

  fromPartial(object: DeepPartial<Minter>): Minter {
    const message = createBaseMinter();
    message.inflation = object.inflation ?? "";
    message.annualProvisions = object.annualProvisions ?? "";
    return message;
  }

};

function createBaseParams(): Params {
  return {
    mintDenom: "",
    inflationRateChange: "",
    inflationMax: "",
    inflationMin: "",
    goalBonded: "",
    blocksPerYear: Long.UZERO
  };
}

export const Params = {
  encode(message: Params, writer: _m0.Writer = _m0.Writer.create()): _m0.Writer {
    if (message.mintDenom !== "") {
      writer.uint32(10).string(message.mintDenom);
    }

    if (message.inflationRateChange !== "") {
      writer.uint32(18).string(message.inflationRateChange);
    }

    if (message.inflationMax !== "") {
      writer.uint32(26).string(message.inflationMax);
    }

    if (message.inflationMin !== "") {
      writer.uint32(34).string(message.inflationMin);
    }

    if (message.goalBonded !== "") {
      writer.uint32(42).string(message.goalBonded);
    }

    if (!message.blocksPerYear.isZero()) {
      writer.uint32(48).uint64(message.blocksPerYear);
    }

    return writer;
  },

  decode(input: _m0.Reader | Uint8Array, length?: number): Params {
    const reader = input instanceof _m0.Reader ? input : new _m0.Reader(input);
    let end = length === undefined ? reader.len : reader.pos + length;
    const message = createBaseParams();

    while (reader.pos < end) {
      const tag = reader.uint32();

      switch (tag >>> 3) {
        case 1:
          message.mintDenom = reader.string();
          break;

        case 2:
          message.inflationRateChange = reader.string();
          break;

        case 3:
          message.inflationMax = reader.string();
          break;

        case 4:
          message.inflationMin = reader.string();
          break;

        case 5:
          message.goalBonded = reader.string();
          break;

        case 6:
          message.blocksPerYear = (reader.uint64() as Long);
          break;

        default:
          reader.skipType(tag & 7);
          break;
      }
    }

    return message;
  },

  fromPartial(object: DeepPartial<Params>): Params {
    const message = createBaseParams();
    message.mintDenom = object.mintDenom ?? "";
    message.inflationRateChange = object.inflationRateChange ?? "";
    message.inflationMax = object.inflationMax ?? "";
    message.inflationMin = object.inflationMin ?? "";
    message.goalBonded = object.goalBonded ?? "";
    message.blocksPerYear = object.blocksPerYear !== undefined && object.blocksPerYear !== null ? Long.fromValue(object.blocksPerYear) : Long.UZERO;
    return message;
  }

};

==> interchain-rpc-1.9.0-rc.0.tgz: package/src/codegen/cosmos/mint/v1beta1/mint.ts <==
import * as _m0 from "protobufjs/minimal";
import { Long } from "../../../helpers";
/** Minter represents the minting state. */

export interface Minter {
  /** current annual inflation rate */
  inflation: string;
  /** current annual expected provisions */

  annualProvisions: string;
}
/** Minter represents the minting state. */

export interface MinterSDKType {
  /** current annual inflation rate */
  inflation: string;
  /** current annual expected provisions */

  annual_provisions: string;
}
/** Params holds parameters for the mint module. */

export interface Params {
  /** type of coin to mint */
  mintDenom: string;
  /** maximum annual change in inflation rate */

  inflationRateChange: string;
  /** maximum inflation rate */

  inflationMax: string;
  /** minimum inflation rate */

  inflationMin: string;
  /** goal of percent bonded atoms */

  goalBonded: string;
  /** expected blocks per year */

  blocksPerYear: Long;
}
/** Params holds parameters for the mint module. */

export interface ParamsSDKType {
  /** type of coin to mint */
  mint_denom: string;
  /** maximum annual change in inflation rate */

  inflation_rate_change: string;
  /** maximum inflation rate */

  inflation_max: string;
  /** minimum inflation rate */

  inflation_min: string;
  /** goal of percent bonded atoms */

  goal_bonded: string;
  /** expected blocks per year */

  blocks_per_year: Long;
}

function createBaseMinter(): Minter {
  return {
    inflation: "",
    annualProvisions: ""
  };
}

export const Minter = {
  encode(message: Minter, writer: _m0.Writer = _m0.Writer.create()): _m0.Writer {
    if (message.inflation !== "") {
      writer.uint32(10).string(message.inflation);
    }

    if (message.annualProvisions !== "") {
      writer.uint32(18).string(message.annualProvisions);
    }

    return writer;
  },

  decode(input: _m0.Reader | Uint8Array, length?: number): Minter {
    const reader = input instanceof _m0.Reader ? input : new _m0.Reader(input);
    let end = length === undefined ? reader.len : reader.pos + length;
    const message = createBaseMinter();

    while (reader.pos < end) {
      const tag = reader.uint32();

      switch (tag >>> 3) {
        case 1:
          message.inflation = reader.string();
          break;

        case 2:
          message.annualProvisions = reader.string();
          break;

        default:
          reader.skipType(tag & 7);
          break;
      }
    }

    return message;
  },

  fromPartial(object: Partial<Minter>): Minter {
    const message = createBaseMinter();
    message.inflation = object.inflation ?? "";
    message.annualProvisions = object.annualProvisions ?? "";
    return message;
  }

};

function createBaseParams(): Params {
  return {
    mintDenom: "",
    inflationRateChange: "",
    inflationMax: "",
    inflationMin: "",
    goalBonded: "",
    blocksPerYear: Long.UZERO
  };
}

export const Params = {
  encode(message: Params, writer: _m0.Writer = _m0.Writer.create()): _m0.Writer {
    if (message.mintDenom !== "") {
      writer.uint32(10).string(message.mintDenom);
    }

    if (message.inflationRateChange !== "") {
      writer.uint32(18).string(message.inflationRateChange);
    }

    if (message.inflationMax !== "") {
      writer.uint32(26).string(message.inflationMax);
    }

    if (message.inflationMin !== "") {
      writer.uint32(34).string(message.inflationMin);
    }

    if (message.goalBonded !== "") {
      writer.uint32(42).string(message.goalBonded);
    }

    if (!message.blocksPerYear.isZero()) {
      writer.uint32(48).uint64(message.blocksPerYear);
    }

    return writer;
  },

  decode(input: _m0.Reader | Uint8Array, length?: number): Params {
    const reader = input instanceof _m0.Reader ? input : new _m0.Reader(input);
    let end = length === undefined ? reader.len : reader.pos + length;
    const message = createBaseParams();

    while (reader.pos < end) {
      const tag = reader.uint32();

      switch (tag >>> 3) {
        case 1:
          message.mintDenom = reader.string();
          break;

        case 2:
          message.inflationRateChange = reader.string();
          break;

        case 3:
          message.inflationMax = reader.string();
          break;

        case 4:
          message.inflationMin = reader.string();
          break;

        case 5:
          message.goalBonded = reader.string();
          break;

        case 6:
          message.blocksPerYear = (reader.uint64() as Long);
          break;

        default:
          reader.skipType(tag & 7);
          break;
      }
    }

    return message;
  },

  fromPartial(object: Partial<Params>): Params {
    const message = createBaseParams();
    message.mintDenom = object.mintDenom ?? "";
    message.inflationRateChange = object.inflationRateChange ?? "";
    message.inflationMax = object.inflationMax ?? "";
    message.inflationMin = object.inflationMin ?? "";
    message.goalBonded = object.goalBonded ?? "";
    message.blocksPerYear = object.blocksPerYear !== undefined && object.blocksPerYear !== null ? Long.fromValue(object.blocksPerYear) : Long.UZERO;
    return message;
  }

};
